@@ -1,3 +1,4 @@
+from typing import Optional, Callable, Any
 from functools import wraps
 from threading import Semaphore
 
@@ -9,7 +10,7 @@ def sure_release(semaphore: Semaphore, func, *args, **kwargs):
         semaphore.release()
 
 
-def retry(times: int):
+def retry(times: int, except_callback: Optional[Callable[..., Any]] = None):
     """Retry times when func fails"""
 
     def wrap(func):
@@ -24,6 +25,9 @@ def retry(times: int):
                     r = func(*args, **kwargs)
                     return r
                 except Exception as err:
+                    if except_callback is not None:
+                        except_callback(err, i)
+
                     if i == times:
                         raise err
 
